Documentation
¶
Index ¶
- type Mode
- type Model
- func (m *Model) DisplaySignalCount() int
- func (m *Model) EnterSelectMode()
- func (m *Model) ExitSelectMode()
- func (m Model) ExtractSignalNames() []string
- func (m *Model) GlobalIndexToVisible(globalIdx int) int
- func (m *Model) GoToEnd()
- func (m *Model) GoToStart()
- func (m Model) Init() tea.Cmd
- func (m *Model) MoveSignalDown()
- func (m *Model) MoveSignalUp()
- func (m *Model) NextChange()
- func (m *Model) PrevChange()
- func (m *Model) ResetZoom()
- func (m *Model) RestoreViewState(state ViewState)
- func (m *Model) ScrollTimeLeft(amount uint64)
- func (m *Model) ScrollTimeRight(amount uint64)
- func (m *Model) Search(query string)
- func (m Model) SelectedSignalData() *vcd.SignalData
- func (m *Model) SetAllSignalsVisible(visible bool)
- func (m *Model) ToggleSelectMode()
- func (m *Model) ToggleSignalVisibility()
- func (m *Model) VisibleIndexToGlobal(visibleIdx int) int
- func (m Model) VisibleSignalCount() int
- func (m *Model) VisibleSignalIndices() []int
- func (m Model) WaveformWidth() int
- func (m *Model) ZoomIn()
- func (m *Model) ZoomOut()
- type ViewState
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Model ¶
type Model struct {
// VCD data
VCD *vcd.VCDFile
Signals []*vcd.SignalData // Sorted signal list
Filename string
// Viewport state
TimeStart uint64 // Start time of visible window
TimeEnd uint64 // End time of visible window
Zoom float64 // Zoom level (1.0 = default)
TimePerChar uint64 // Time units per character
// Cursor state
CursorTime uint64 // Current cursor position in time
CursorVisible bool
// Selection state
SelectedSignal int // Index of selected signal
// Signal visibility
SignalVisible []bool // 各信号の表示/非表示(Signalsと同じ長さ)
SelectMode bool // true: 全信号選択モード
// Display state
Width int // Terminal width
Height int // Terminal height
SignalPaneWidth int // Width of signal name pane
// Mode
Mode Mode
SearchQuery string
SearchResult []int // Indices of matching signals
// Scroll state for signal list
SignalScrollOffset int
// File watching state
WatchError string
ReloadError string
LastReloadTime time.Time
}
Model is the main application state
func (*Model) DisplaySignalCount ¶
DisplaySignalCount returns the number of signals to display (depends on mode)
func (*Model) EnterSelectMode ¶
func (m *Model) EnterSelectMode()
EnterSelectMode enters signal selection mode
func (*Model) ExitSelectMode ¶
func (m *Model) ExitSelectMode()
ExitSelectMode exits signal selection mode
func (Model) ExtractSignalNames ¶
ExtractSignalNames extracts signal names for state preservation
func (*Model) GlobalIndexToVisible ¶
GlobalIndexToVisible converts a global signal index to visible index (-1 if not visible)
func (*Model) NextChange ¶
func (m *Model) NextChange()
NextChange moves cursor to next value change of selected signal
func (*Model) PrevChange ¶
func (m *Model) PrevChange()
PrevChange moves cursor to previous value change of selected signal
func (*Model) RestoreViewState ¶
RestoreViewState restores the view state after VCD reload
func (*Model) ScrollTimeLeft ¶
ScrollTimeLeft scrolls the time window left
func (*Model) ScrollTimeRight ¶
ScrollTimeRight scrolls the time window right
func (Model) SelectedSignalData ¶
func (m Model) SelectedSignalData() *vcd.SignalData
SelectedSignalData returns the currently selected signal data
func (*Model) SetAllSignalsVisible ¶
SetAllSignalsVisible sets visibility for all signals
func (*Model) ToggleSelectMode ¶
func (m *Model) ToggleSelectMode()
ToggleSelectMode toggles signal selection mode
func (*Model) ToggleSignalVisibility ¶
func (m *Model) ToggleSignalVisibility()
ToggleSignalVisibility toggles visibility of the selected signal
func (*Model) VisibleIndexToGlobal ¶
VisibleIndexToGlobal converts a visible signal index to global index
func (Model) VisibleSignalCount ¶
VisibleSignalCount returns the number of signals that can be displayed
func (*Model) VisibleSignalIndices ¶
VisibleSignalIndices returns indices of visible signals
func (Model) WaveformWidth ¶
WaveformWidth returns the width available for waveform display