watcher

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 14, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WatchFile

func WatchFile(filename string) tea.Cmd

WatchFile creates a command that watches a file for changes

Types

type FileChangedMsg

type FileChangedMsg struct {
	Filename string
	Error    error
}

FileChangedMsg is sent when the watched file changes

type FileWatchErrorMsg

type FileWatchErrorMsg struct {
	Error error
}

FileWatchErrorMsg is sent when the file watcher encounters an error

Jump to